@@ -36,10 +36,10 @@ class FlashCalculationInput:
 
         flash_type = self.flash_type.value
 
-        units: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.units, Unset):
-            units = self.units.to_dict()
-
+        #units: Union[Unset, Dict[str, Any]] = UNSET
+        #if not isinstance(self.units, Unset):
+        #    units = self.units.to_dict()
+        units = self.units
         fluid_id = self.fluid_id
         temperature = self.temperature
         pressure = self.pressure
@@ -87,12 +87,14 @@ class FlashCalculationInput:
 
         flash_type = FlashCalculationType(d.pop("flashType"))
 
-        _units = d.pop("units", UNSET)
-        units: Union[Unset, Units]
-        if isinstance(_units, Unset):
-            units = UNSET
-        else:
-            units = Units.from_dict(_units)
+        #_units = d.pop("units", UNSET)
+        #units: Union[Unset, Units]
+        #if isinstance(_units, Unset):
+        #    units = UNSET
+        #else:
+        #    units = Units.from_dict(_units)
+
+        units = d.pop("units", UNSET)
 
         fluid_id = d.pop("fluidId", UNSET)
 
