@@ -6,7 +6,7 @@ from onlinepvt.online_pvt_client import OnlinePvtClient
 @pytest.mark.asyncio
 async def test_call_flash():
     client = OnlinePvtClient(
-        "https://api.onlinepvt.com", "UserId", "AccessSecret")
+        "https://api.onlinepvt.com", "52E6292C-BC9B-402F-83D8-D59D08223BC1", "##glD47#al!=(d+53ES3?qW")
 
     input = client.get_flash_input()
     input.temperature = 445
